/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.area.field.explorer;

import java.util.List;
import nl.cloudfarming.client.area.field.FieldLayer;
import nl.cloudfarming.client.area.field.HelpLineLayer;
import nl.cloudfarming.client.geoviewer.Layer;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.lookup.Lookups;

/**
 * 2 nodes, one for fields, one for lines.
 *
 * @author Gerben Feenstra
 */
public class GeometryRootNodeFactory extends ChildFactory<Layer> {

    private FieldLayer fieldLayer = null;
    private HelpLineLayer lineLayer = null;

    public GeometryRootNodeFactory(FieldLayer fieldLayer, HelpLineLayer lineLayer) {
        this.fieldLayer = fieldLayer;
        this.lineLayer = lineLayer;
    }

    @Override
    protected boolean createKeys(List<Layer> toPopulate) {
        toPopulate.add(fieldLayer);
        toPopulate.add(lineLayer);
        return true;
    }

    @Override
    protected Node createNodeForKey(Layer key) {
        Children children;
        if (key instanceof FieldLayer){
            children = Children.create(new FieldNodeFactory(),true);
        }else if(key instanceof HelpLineLayer){
            children = Children.create(new HelpLineNodeFactory(),true);
        }else{
            children = Children.LEAF;
        }
        return new GeometryChildNode(children, key){
            
        };
    }
    
    class GeometryChildNode extends AbstractNode{
        public GeometryChildNode(Children children, Layer layer) {
            super(children, Lookups.fixed(layer));
            setIconBaseWithExtension(Layer.LAYER_NODE_ICON_BASE);
            setDisplayName(layer.getName());
        }
    }
}
